@@ -8,6 +8,10 @@
 #' @importFrom shiny shinyApp
 #' @importFrom golem with_golem_options
 run_app <- function(
+  #onStart = NULL,
+  #options = list(),
+  #enableBookmarking = NULL,
+  #uiPattern = "/",
   ...
 ) {
   with_golem_options(
@@ -19,6 +23,7 @@ run_app <- function(
       #enableBookmarking = enableBookmarking,
       #uiPattern = uiPattern
     ),
-    golem_opts = list(...)
+    #golem_opts = list(...)
+    golem_opts = list(Olympic=OlympicRshiny::Olympic)
   )
 }
